@@ -21,6 +21,8 @@
 #include "nodes/primnodes.h"
 #include "nodes/execnodes.h"
 
+extern int remote_param_fetch_threshold;
+
 typedef struct VarPickerCtx
 {
 	/*
@@ -31,15 +33,13 @@ typedef struct VarPickerCtx
 	 * */
 	Var **target_cols;
 	MemoryContext mctx;
-	int nvars;
-	int nvar_buf;
+	int nvars, nvar_buf;
 
 	/*
-	  The expr has a agg func call without column reference, e.g. 
-	  count(*), count(1), sum(1), etc. Such a call has no args list and
-	  no vars but it should be serialized.
-	*/
-	bool has_agg;
+	 * Whether the expr contains columns of other tables. 
+	 * */
+	bool has_alien_cols;
+
 	/*
 	 * If there are no vars to reference target rel, and all Nodes of the
 	 * targetEntry->expr are locally
@@ -57,57 +57,47 @@ typedef struct VarPickerCtx
 	int local_unevaluables;
 
 	/*
-	  PlaceHolderVar::phexpr found from an expression, we want to simply
-	  extract such PHV's exprs.
-	*/
-	List *phv_expr_list;
-	
-	/* List of phvs which assigned alias and should be treated as normal vars */
-	List *nonrecursive_exprs;
+	 * Range table index of target relation to scan.
+	 * */
+	int scanrelid;
 
-	/* Do not recursively walk with aggregate function */
-	bool nonrecursive_agg;
-
-	List *aggref_pptr_list;
+	bool check_alien_vars;
 } VarPickerCtx;
 
 struct RemotePrintExprContext;
-
 /*
- * Used to construct sql for pushdownable update&&delete 
+ * Used to construct sql for pushdownable update&&delete
  */
 typedef struct RemoteUD
 {
-	ModifyTableState *mtstate;
-	ResultRelInfo *relinfo;
-	int planIndex;
-	int index;		 /* Index of current result relation */
-	Relation rel;	 /* Current result relation */
-	int rti;		 /* RTE number of current result relation */
-	List *tlist;	 /* Update target list */
-	List *qual;		 /* Where clause of current result relation */
-	PlanState *from; /* From clause */
-	List *sortlist;	 /* Sort clause */
-	List *sortop;	 /* Sort operator */
-	List *sortnullfirst; 
-	int64_t limit;	 /* Limit clause */
-	List *rellist;	 /* All of the result relation */
-	List *quallist;	 /* All of the qual of result relation */
+   ModifyTableState *mtstate;
+   int planIndex;
+   int index;       /* Index of current result relation */
+   Relation rel;    /* Current result relation */
+   int rti;         /* RTE number of current result relation */
+   List *tlist;     /* Update target list */
+   List *qual;      /* Where clause of current result relation */
+   PlanState *from; /* From clause */
+   List *sortlist;  /* Sort clause */
+   List *sortop;    /* Sort operator */
+   List *sortnullfirst;
+   int64_t limit;   /* Limit clause */
+   List *rellist;   /* All of the result relation */
+   List *quallist;  /* All of the qual of result relation */
+   ResultRelInfo *relinfo;
 } RemoteUD;
 
 #define RemoteUDRelations(p) \
-	(list_length((p)->rellist))
+   (list_length((p)->rellist))
 
 extern void RemoteUDSetup(PlanState *planstate, RemoteUD *remote_updel);
 extern bool RemoteUDNext(RemoteUD *remote_updel, struct RemotePrintExprContext *rpec, StringInfo sql, Oid *shardid);
 extern bool RemoteUDEOF(RemoteUD *remote_updel);
 
-extern int remote_param_fetch_threshold;
-
 extern bool CheckPartitionKeyModified(Relation,  Index attrno);
+extern bool CanPushdownRemoteUD(PlanState *state, List *unused_tl, int *nleafs, const char **reaseon);
 
-extern bool CanPushdownRemoteUD(PlanState *state, List *unused_tl, int *leafs, const char **reaseon);
-extern bool var_picker(Node **ppnode, struct VarPickerCtx*ctx);
-extern bool var_picker_hdlr(Node **ppnode, struct VarPickerCtx*ctx);
+extern bool var_picker(Node *node, VarPickerCtx*ctx);
+extern TupleDesc expandTupleDesc2(TupleDesc tpd);
 extern void reset_var_picker_ctx(VarPickerCtx *vpc);
 #endif // !REMOTE_DML_H
