@@ -381,18 +381,6 @@ DECLARE_UNIQUE_INDEX(pg_cluster_meta_id_index, 6673, on pg_cluster_meta using bt
 #define ClusterMetaIdIndexId 6673
 DECLARE_UNIQUE_INDEX(pg_ddl_log_dbid_index, 6674, on pg_ddl_log_progress using btree(dbid oid_ops));
 #define DDLLogDbidIndexId 6674
-DECLARE_UNIQUE_INDEX(pg_comp_nodes_id_index, 6675, on pg_comp_nodes using btree(id oid_ops));
-#define CompNodesIdIndex 6675
-
-DECLARE_UNIQUE_INDEX(pg_mysql_charset_mapping_pg_charset_enc_idx, 6676, on pg_mysql_charset_mapping using btree(pg_charset_enc int4_ops));
-#define PgMysqlCharsetMappingPgcsencIdx 6676
-
-DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_coll_idx, 6677, on pg_mysql_collation_mapping using btree(mysql_collation_code int4_ops));
-#define PgMysqlCollsMappingMysqlCollIdx 6677
-DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_cs_coll_names_idx, 6678, on pg_mysql_collation_mapping using btree(mysql_csname name_ops, mysql_collname name_ops));
-#define PgMysqlCollsMappingMysqlCsCollNamesIdx 6678
-DECLARE_UNIQUE_INDEX(pg_mysql_collation_mapping_mysql_coll_name_idx, 6679, on pg_mysql_collation_mapping using btree(mysql_collname name_ops));
-#define PgMysqlCollsMappingMysqlCollNameIdx 6679
 
 DECLARE_UNIQUE_INDEX(pg_proc_map_proname_args_nsp_index, 7000, on pg_proc_map using btree(proname name_ops, proargtypes oidvector_ops, pronamespace oid_ops));
 #define ProcedureMapNameArgsNspIndexId 7000
