@@ -6,7 +6,6 @@
 #include "nodes/execnodes.h"
 #include "nodes/pg_list.h"
 #include "nodes/print.h"
-
 typedef struct ScanTupleGenContext
 {
 	List *exprs;
@@ -14,8 +13,6 @@ typedef struct ScanTupleGenContext
 	EState *estate;
 	TupleDesc tupledesc;
 
-	List *bottom_hvs;
-	List *bottom_hvs_exprs;
 	List *unpushable_exprs;
 
 	VarPickerCtx vpc;
@@ -28,4 +25,4 @@ extern Var* lookup_scanvar_for_expr(ScanTupleGenContext *context, Expr *expr);
 extern bool alloc_scanvar_for_expr(ScanTupleGenContext *context, Expr *expr);
 extern Node *replace_expr_with_scanvar_mutator(Node *node, ScanTupleGenContext *context);
 extern Node *restore_scanvar_with_expr_mutator(Node *node, ScanTupleGenContext *context);
-#endif
+#endif
\ No newline at end of file
