@@ -31,8 +31,7 @@
 #include "utils/algos.h"
 #include "nodes/tidbitmap.h"
 #include "storage/condition_variable.h"
-//#include "sharding/sharding_conn.h"
-#include "sharding/stmt_hdl.h"
+#include "sharding/sharding_conn.h"
 
 
 struct PlanState;				/* forward references in this file */
@@ -41,6 +40,7 @@ struct ExprState;
 struct ExprContext;
 struct ExprEvalStep;			/* avoid including execExpr.h everywhere */
 
+
 struct EnumLabelOid;
 typedef struct TypeInputInfo
 {
@@ -504,9 +504,6 @@ typedef struct ResultRelInfo
  * Master working state for an Executor invocation
  * ----------------
  */
-#define REPLICA_READ_NONE	0
-#define REPLICA_READ_FALSE	-1
-#define REPLICA_READ_TRUE	1
 typedef struct EState
 {
 	NodeTag		type;
@@ -613,9 +610,6 @@ typedef struct EState
 	int			es_jit_flags;
 	struct JitContext *es_jit;
 	struct JitInstrumentation *es_jit_worker_instr;
-	
-	/* Strategy of replica read */
-	int es_replica_read;
 } EState;
 
 
@@ -1075,10 +1069,9 @@ typedef struct ProjectSetState
 	MemoryContext argcontext;	/* context for SRF arguments */
 } ProjectSetState;
 
-struct AsyncStmtInfo;
 typedef struct RemoteModifyState
 {
-	struct AsyncStmtInfo *asi;         /* communication channel with storage node. */
+	AsyncStmtInfo *asi;         /* communication channel with storage node. */
 	StringInfoData remote_dml;
 	StmtSafeHandle handle;
 } RemoteModifyState;
@@ -1109,9 +1102,9 @@ typedef struct ModifyTableState
 	bool is_pushdown_updel;	   /* true if this query is pushdownable delete/update */
 	List *pushdown_returning;  /* the returning clause of the pushdownable delete/update */
 	struct RemoteUD *remote_updel; /* printer generating pushed delete/update*/
-	StmtSafeHandle *active_stmts;	   /* active AsyncStmtInfo */
-	int nactive_stmts;
+	StmtSafeHandle *active_stmts;	   /* active stmts array */
 	int max_actieve_stmts;
+	int nactive_stmts;
 
 	TupleTableSlot *remoteReturningTupleSlot;
 	TypeInputInfo *typeInputInfo;
@@ -1138,8 +1131,6 @@ typedef struct ModifyTableState
 	/* cached tuple conversion map to accelerate tupconv_map_for_partition()*/
 	int mt_current_partidx;
 
-	/* cache unconsumed tuples when give up connection */
-	Tuplestorestate *tuplestorestate;
 } ModifyTableState;
 
 /* ----------------
@@ -1174,7 +1165,6 @@ struct AppendState
 	struct PartitionPruneState *as_prune_state;
 	Bitmapset  *as_valid_subplans;
 	bool		(*choose_next_subplan) (AppendState *);
-	bool		keep_order;
 };
 
 /* ----------------
@@ -1275,50 +1265,67 @@ typedef struct ScanState
 	TupleTableSlot *ss_ScanTupleSlot;
 } ScanState;
 
-struct SortColRef;
 
-/*
- * The table name conflict when generating remote sql
- */
-struct RangeTblEntry;
-typedef struct TableNameConflict
-{
-	int relid;
-	char *name;			/* The orignal name of the conflict table */
-	char *newName;		/* The modified name of the conflict table */
-	struct RangeTblEntry *rte;
-} TableNameConflict;
-
-typedef struct RemotePlanState
+typedef struct RemoteScanState
 {
 	ScanState	ss;				/* its first field is NodeTag */
-	/* The target shard id*/
-	Oid shardid;
-	/* The prepared remote sql */
 	StringInfoData remote_sql;
-	StringInfoData sql_param_digest;
-	/* The scanlist of remote sql */
-	List *scanlist;
-	 /* communication channel with storage node. */
-	struct AsyncStmtInfo *asi;
+	AsyncStmtInfo *asi;         /* communication channel with storage node. */
 	StmtSafeHandle handle;
 	TypeInputInfo *typeInputInfo;
-	/**
-	 * when this is in a correlated subquery, do we use dependent outer param
-	 * values to fetch each portion of qualified rows on each rescan, or do we fetch
-	 * all rows that match quals containing no dependent params all at once.
-	 * It's generally faster and less costly to do it the 2nd way, unless there
-	 * are too many qualified rows.
-	 */
-	bool		param_driven;
-	List 		*param;
+	/*
+	 * Attr Nums in this set is a 'long expression', i.e. longer than NAMEDATALEN.
+	 * Suppose the i'th 1 bit in long_exprs_bmp denotes number x, then the
+	 * tupdesc->attrs[x].attname doesn't contail complete expr text, need to use
+	 * long_exprs[i] instead.
+	 * */
+	Bitmapset *long_exprs_bmp;
+	List *long_exprs;
 
 	/*
-	  need to rewind, most likely its resultset is used as inner node result
-	  of a join. If so store result rather than use result.
-	*/
+	 * The TupleDesc in ss.ps.scandesc may be allocated with more
+	 * FormData_pg_attribute slots than ss.ps.scandesc->natts, this field
+	 * stores the real capacity of ss.ps.scandesc->attrs array, in order to
+	 * store extra attrs for quals.
+	 * */
+	int scandesc_natts_cap;
+	bool fetches_remote_data;
+
+	/* when this is in a correlated subquery, do we use dependent outer param
+	   values to fetch each portion of qualified rows on each rescan, or do we fetch
+	   all rows that match quals containing no dependent params all at once.
+	   It's generally faster and less costly to do it the 2nd way, unless there
+	   are too many qualified rows.
+	   */
+	bool		param_driven;
+
+	/*
+	   results of this remote scan is used for EXISTS() checks thus only 1 row
+	   needs to be returned.
+	   */
+	bool		check_exists;
+
+	/*
+	   need to rewind, most likely its resultset is used as inner node result
+	   of a join. If so store result rather than use result.
+	   */
 	bool will_rewind;
-} RemotePlanState;
+
+	/* Unpushable target list */
+	List *unpushable_tl;
+
+	/* Generated vars of scantuple, and the coresponding exprs */
+	List *scanvars;
+	List *scanexprs;
+
+	/* Origial plan->qual */
+	List *orignal_qual;
+
+	/* Quals pushdown to the storage */
+	List *quals_pushdown;
+	List *having_pushdown;
+
+} RemoteScanState;
 
 /* ----------------
  *	 SeqScanState information
@@ -1981,7 +1988,6 @@ typedef struct SortState
 	int64		bound_Done;		/* value of bound we did the sort with */
 	void	   *tuplesortstate; /* private state of tuplesort.c */
 	SharedSortInfo *shared_info;	/* one entry per worker */
-	bool		bypass;
 } SortState;
 
 /* ---------------------
