@@ -68,8 +68,7 @@ typedef enum NodeTag
 	T_WorkTableScan,
 	T_ForeignScan,
 	T_CustomScan,
-	T_RemotePath,
-	T_RemotePlan,
+	T_RemoteScan,
 	T_Join,
 	T_NestLoop,
 	T_MergeJoin,
@@ -126,6 +125,7 @@ typedef enum NodeTag
 	T_WorkTableScanState,
 	T_ForeignScanState,
 	T_CustomScanState,
+	T_RemoteScanState,
 	T_JoinState,
 	T_NestLoopState,
 	T_MergeJoinState,
@@ -142,7 +142,6 @@ typedef enum NodeTag
 	T_SetOpState,
 	T_LockRowsState,
 	T_LimitState,
-	T_RemotePlanState,
 
 	/*
 	 * TAGS FOR PRIMITIVE NODES (primnodes.h)
@@ -422,19 +421,6 @@ typedef enum NodeTag
 	T_CreateStatsStmt,
 	T_AlterCollationStmt,
 	T_CallStmt,
-	T_UseStmt,
-	T_ShowDiagnoStmt,
-	T_KillStmt,
-	T_ShowDatabasesStmt,
-	T_ShowSchemasStmt,
-	T_ShowTablesStmt,
-	T_ShowCreateTableStmt,
-	T_ShowProcessListStmt,
-	T_SendShardStmt,
-	T_FetchMySQLVarStmt,
-	T_MySQLVarRef,
-	T_ShowCollationStmt,
-	T_MultiVariableSetStmt,
 
 	/*
 	 * TAGS FOR PARSE TREE NODES (parsenodes.h)
