@@ -95,7 +95,7 @@ typedef struct PlannedStmt
 	List	   *paramExecTypes; /* type OIDs for PARAM_EXEC Params */
 
 	Node	   *utilityStmt;	/* non-null if this is utility stmt */
-	
+
 	/* statement location in source string (copied from Query) */
 	int			stmt_location;	/* start location, or -1 if unknown */
 	int			stmt_len;		/* length in bytes; 0 means "rest of string" */
@@ -275,9 +275,6 @@ typedef struct Append
 
 	/* Info for run-time subplan pruning; NULL if we're not doing that */
 	struct PartitionPruneInfo *part_prune_info;
-
-	/* Create a worker for each child, and keep result order of it */
-	bool  keep_order;
 } Append;
 
 /* ----------------
@@ -363,21 +360,11 @@ typedef struct RemoteScan
 	with 1st column of the target table, though we could modify the targetlist
 	to contain a single boolean column. */
 	bool		check_exists;
-
 	/*
 	  True iff this node has a Material parent. This is to prevent multiple
 	  Materialization to the same RS node when it's referenced by multiple places.
-	  e.g. a SubPlan referenced in a ProjectionInfo exprstate but not in the
-	  targetlist.
 	*/
 	bool		materialized;
-
-	/*
-	  Set to true if we want to sort the pushed down agg grouped rows so we
-	  can do a quick merge in computing nodes.
-	*/
-	bool	sort_groups;
-
 	/*
 	 * TODO:
 	 * we don't need to decide for storage node which index to use to fetch
@@ -398,37 +385,6 @@ typedef struct RemoteScan
 	List	   *indexorderbyops;
 	ScanDirection indexorderdir;
 	 * */
-
-	/*
-	  If not NULL, a list of exprs representing the grouping exprs.
-	  All of it must be able to push down, and this has been checked already
-	  during planning.
-	*/
-	List *grouping_exprs;
-	/*
-	  If not NULL, a list of exprs representing the having clause quals.
-	  During planning these are all having quals of a remote pushed down agg.
-	  During execution these are having quals that have to be kept in computing
-	  node, and there may be more having quals which are pushed down.
-
-	  It's OK if some or none of it can be pushed down, we can simply
-	  use them as row filters to filter unqualified agg rows in computing
-	  node.
-	*/
-	List *havingQuals;
-
-
-	/*
-	 Saved target list before set_plan_refs(), we need this to find out the source of
-	 PlaceHolderVar used by the upper level RemoteJoin when generating remote sql
-	 */
-	List *targetList;
-
-	/* PlaceHolderVars generated in current scan or join */
-	List *generatedPhvs;
-
-	/* PlaceHolderVars generated by scans or joins below */
-	List *referencedPhvs;
 } RemoteScan;
 
 typedef struct Scan
@@ -824,60 +780,6 @@ typedef struct MergeJoin
 	bool	   *mergeNullsFirst;	/* per-clause nulls ordering */
 } MergeJoin;
 
-
-/*
-  dzw: push down Joins whose left and right RS node is on the same shard.
-  And this can be extended to push down a subtree with more RS/RJ/RSO nodes
-  that are on the same shard.
-  For such a subtree we simply produce one RJ node, which we produce SQL as
-  if doing a mid-order tree traverse. And we use rj_plans to refer to such
-  plan nodes, and the RJ.join.plan.left/right_tree are not used.
-  We use parse tree to produce RJPath nodes which are then used to produce the
-  RJ subtree, so we can avoid optimization for the subtrees
-  that can be totally pushed down.
-  OLD push down can be done to an RJ/RSO node just the same as done to an RS
-  node. materialization handles an RJ/RSO just the same as an RS node.
-
-  RemoteJoin isn't a Join node in computing node perspective, it's a special
-  remotescan targeting a specific shard and involving multiple tables doing
-  join on the target shard.
-*/
-typedef struct RemoteJoin
-{
-	RemoteScan	remote_scan;
-	JoinType	jointype;
-	bool		inner_unique;
-	List	   *joinqual;		/* JOIN quals (in addition to plan.qual) */
-	Oid			rj_shardid;
-} RemoteJoin;
-
-typedef struct RemtePlan
-{
-	Plan plan;
-	/* The target shard */
-	Oid shard;
-	/* The base relation id if it is a table scan */
-	Index baserelid;
-	/* The geneated prepared sql*/
-	const char *prepared_sql;
-
-	/* Fields needed by update/delete to construct the update/delete query */
-	List *topwhere;
-	List *sortexpr;
-	List *sortop;
-	List *sortnullfirst;
-	Node *limitoff;
-	Node *limitcnt;
-
-	/* The parameters refered in prepared_sql*/
-	List *params;
-	List *param_locations;
-	/* The target list of the prepared_sql */
-	List *scan_list;
-
-	/* The orignal target list, saved for explain */
-	List *original_target_list;
-} RemotePlan;
 /* ----------------
  *		hash join node
  * ----------------
@@ -895,6 +797,11 @@ typedef struct HashJoin
 typedef struct Material
 {
 	Plan		plan;
+
+	/*
+  	  dzw: fetch all rows at once in ExecInitMaterial()/rescan for remote table.
+	*/
+	bool		remote_fetch_all;
 } Material;
 
 /* ----------------
@@ -1068,7 +975,6 @@ typedef struct SetOp
 	long		numGroups;		/* estimated number of groups in input */
 } SetOp;
 
-
 /* ----------------
  *		lock-rows node
  *
