@@ -19,33 +19,6 @@
 #include "nodes/params.h"
 
 #define nodeDisplay(x)		pprint(x)
-
-/*
- * Print the PlaceHolderVar with newly generated alias if it is just a reference
- */
-struct PlaceHolderVar;
-typedef struct PhvAlias
-{
-	struct PlaceHolderVar *phv;
-	char *alias;
-} PhvAlias;
-
-typedef struct VarAlias
-{
-	Var *var;
-	char *alias;
-	int levelno;
-} VarAlias;
-/**
- * @brief Parameter information collected in snprint_expr
- */
-typedef struct ParamPlaceholder
-{
-       Expr *param;
-       /* The placeholder's location in printed sql */
-       int location;
-} ParamPlaceholder;
-
 typedef struct RemotePrintExprContext
 {
 	EState *estate;
@@ -56,27 +29,12 @@ typedef struct RemotePrintExprContext
 	ParamExecData *rpec_param_exec_vals;
 	ParamListInfo rpec_param_list_info;
 
-	/* True if print param/unsafe func as '?' */
-	bool make_prepare_stmt;
-	/* Information abort the param (i.e. position in sql)*/
-	List *param_placeholders;
-	/* Information abort the unsafe function */
-	List *unsafe_func_placeholder;
-
 	/*
-	  If true, param node will be executed if it does not refer to
-	  external parameters, otherwise it will be treated unsupported
-	*/
+	 * If true, param node will be executed if it does not refer to
+	 * external parameters, otherwise it will be treated unsupported
+	 */
 	bool exec_param_quals;
-
-	/* Placeholder vars that assigned aliases */
-	List *phv_alias;
-
-	/* Vars that assigned aliases */
-	List *var_alias;
-
-	/* Print var with relname, i.e. t1.a */
-	bool full_varname;
+	int num_vals;
 
 	/* Column name of excluded table in on conflict clause */
 	List *excluded_table_columns;
@@ -89,7 +47,6 @@ typedef struct RemotePrintExprContext
 } RemotePrintExprContext;
 
 extern void InitRemotePrintExprContext(RemotePrintExprContext *rpec, List*rtable);
-extern void ResetRemotePrintExprContext(RemotePrintExprContext *rpec, bool b);
 extern void print(const void *obj);
 extern void pprint(const void *obj);
 extern void elog_node_display(int lev, const char *title,
@@ -101,10 +58,6 @@ extern void print_expr(const Node *expr, const List *rtable);
 extern void print_pathkeys(const List *pathkeys, const List *rtable);
 extern void print_tl(const List *tlist, const List *rtable);
 extern void print_slot(TupleTableSlot *slot);
-
-extern bool is_mysql_proc(Oid funcoid);
-extern bool is_mysql_operator(Oid opoid);
-extern bool is_expr_printable(const Expr *expr, RemotePrintExprContext *rpec);
 extern int snprint_expr(StringInfo buf, const Expr *expr, RemotePrintExprContext *rpec);
 extern Oid my_output_funcoid(Oid typid, bool *typIsVarlena);
 #endif							/* PRINT_H */
