@@ -766,7 +766,6 @@ typedef enum
 	WAIT_EVENT_RECOVERY_WAL_ALL,
 	WAIT_EVENT_RECOVERY_WAL_STREAM,
 	WAIT_EVENT_SYSLOGGER_MAIN,
-	WAIT_EVENT_SQLLOGGER_MAIN,
 	WAIT_EVENT_WAL_RECEIVER_MAIN,
 	WAIT_EVENT_WAL_SENDER_MAIN,
 	WAIT_EVENT_WAL_WRITER_MAIN
@@ -835,15 +834,7 @@ typedef enum
 	WAIT_EVENT_REPLICATION_SLOT_DROP,
 	WAIT_EVENT_SAFE_SNAPSHOT,
 	WAIT_EVENT_SYNC_REP,
-	WAIT_EVENT_DEBUG_SYNC,
-	WAIT_EVENT_SEQUENCE_SERVICE,
-	WAIT_EVENT_SHARD_RESULT,
-	WAIT_EVENT_2PC_PREPARE,
-	WAIT_EVENT_2PC_LOG,
-	WAIT_EVENT_2PC_COMMIT,
-	WAIT_EVENT_2PC_ROLLBACK,
-	WAIT_EVENT_GLOBAL_DDL_LOCK,
-	WAIT_EVENT_LATEST_DDL_META,
+	WAIT_EVENT_DEBUG_SYNC
 } WaitEventIPC;
 
 /* ----------
@@ -1005,7 +996,6 @@ typedef struct PgBackendStatus
 
 	/* The entry is valid iff st_procpid > 0, unused if st_procpid == 0 */
 	int			st_procpid;
-	int			st_procvpid;
 
 	/* Type of backends */
 	BackendType st_backendType;
