@@ -50,7 +50,6 @@ enum SysCacheIdentifier
 	CLUSTER_META_NODES,
 	COLLNAMEENCNSP,
 	COLLOID,
-	COMPNODES,
 	CONDEFAULT,
 	CONNAMENSP,
 	CONSTROID,
@@ -76,10 +75,6 @@ enum SysCacheIdentifier
 	OPFAMILYAMNAMENSP,
 	OPFAMILYOID,
 	PARTRELID,
-	PGMYSQLCOLLID,
-	PGMYSQLCOLLNAMEID,
-	PGMYSQLCSCOLLNAMESID,
-	PGMYSQLCSPGENCID,
 	PROCNAMEARGSNSP,
 	PROCOID,
 	PROCMAP,
