@@ -62,7 +62,6 @@ def add_comp_self(install_path, config_template_file, mysql_conn_params, config_
 	       "name" : "comp" + str(maxid),
 	       "ip" : selfip,
 	       "port" : args.port,
-	       "mysql_port": args.mysql_port,
 	       "user": args.user,
 	       "password": args.password,
 	       "datadir" : args.datadir
@@ -71,20 +70,14 @@ def add_comp_self(install_path, config_template_file, mysql_conn_params, config_
     outf = open(config_path, "w")
     json.dump(selfarr, outf, indent=4)
     outf.close()
-
-    valgrindopt = ""
-    if args.valgrind:
-        valgrindopt = "--valgrind"
-
     if args.install:
         if args.docker:
             # install is not performed here currently, since the meta_config file needs to
             os.system("chmod a+rwx /kunlun/env.sh")
             os.system("chown -R postgres:postgres /pgdatadir")
-            os.system("su postgres -c 'cd /kunlun && . ./env.sh; cd $PG_DIR/scripts; python2 install_pg.py --config=./%s --install_ids=%d %s' " % (
-                config_path, maxid, valgrindopt))
+            os.system("su postgres -c 'cd /kunlun && . ./env.sh; cd $PG_DIR/scripts; python2 install_pg.py --config=./%s --install_ids=%d' " % (config_path, maxid))
         else:
-            install_pg.install_pg(config_template_file, install_path, selfobj, args.valgrind)
+            install_pg.install_pg(config_template_file, install_path, selfobj)
     conn = checkserver(selfip, args.port, args.user, args.password, 'postgres')
     if conn is None:
         raise Exception("Computing server is not installed correctly, please check the installation!")
@@ -99,13 +92,12 @@ def add_comp_self(install_path, config_template_file, mysql_conn_params, config_
         if args.docker:
             os.system("sed -i 's/comp_node_id.*=.*/comp_node_id=%d/g' %s/postgresql.conf" % (maxid, args.datadir))
             os.system("su postgres -c 'cd /kunlun && . ./env.sh && pg_ctl -D %s stop -m immediate' " % args.datadir)
-            os.system("su postgres -c 'cd /kunlun && . ./env.sh && cd $PG_DIR/scripts && python2 start_pg.py --port=%d %s' " % (
-                args.port, valgrindopt))
+            os.system("su postgres -c 'cd /kunlun && . ./env.sh && cd $PG_DIR/scripts && python2 start_pg.py --port=%d' " % args.port)
         else:
             os.system("sed -i 's/comp_node_id.*=.*/comp_node_id=%d/g' %s/postgresql.conf" % (maxid, args.datadir))
             os.system(cmd0 + cmd1 + "pg_ctl -D %s stop -m immediate " % args.datadir)
             # start_pg.py set the env well.
-            os.system("python2 start_pg.py --port=%d %s " % (args.port, valgrindopt))
+            os.system("python2 start_pg.py --port=%d " % args.port)
 
 if __name__ == '__main__':
     parser = argparse.ArgumentParser(description='Add current computing node to the cluster.')
@@ -115,12 +107,12 @@ if __name__ == '__main__':
     parser.add_argument('--password', type=str, help="The password")
     parser.add_argument('--hostname', type=str, help="The hostname", default=gethostip())
     parser.add_argument('--port', type=int, help="The port", default=5432)
-    parser.add_argument('--mysql_port', type=int, help="The mysql port", default=3306)
+    # This option does not take effect, it is just used to provide the same interface as enterprise version.
+    parser.add_argument('--mysql_port', type=int, help="The mysql protocol port", default=0)
     parser.add_argument('--datadir', type=str, help="The data directory", default='/pgdatadir')
     parser.add_argument('--install', help="install it first", default=False, action='store_true')
     parser.add_argument('--docker', help="process is in docker container", default=False, action='store_true')
-    parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
-    parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
+    parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
 
     args = parser.parse_args()
 
