@@ -39,6 +39,8 @@ mysql_conn_params['database'] = 'mysql'
 fbootstrap_sql = open(args.bootstrap_sql)
 bootsql = fbootstrap_sql.read()
 # load bootstrap sql file to create metadata tables
+if mysql_conn_params.has_key('is_primary'):
+    del mysql_conn_params['is_primary']
 meta_conn = mysql.connector.connect(**mysql_conn_params)
 meta_conn.autocommit = True
 for result in meta_conn.cmd_query_iter(bootsql):
@@ -54,16 +56,14 @@ meta_cursor0 = meta_conn.cursor()
 meta_cursor0.execute("start transaction")
 meta_cursor.execute("insert into global_configuration(name, value) values(%s, %s)", ("meta_ha_mode", args.ha_mode))
 stmt = "insert into meta_db_nodes(hostaddr, port, user_name, passwd, member_state, sync_state, \
-        degrade_conf_state, degrade_run_state, replica_delay, degrade_conf_time, sync_num, nodemgr_bin_path) \
-        values(%s, %s, %s, %s, %s, %s, %s, %s, 0, 0, 1, %s)"
+        degrade_conf_state, degrade_run_state, replica_delay, degrade_conf_time, sync_num) \
+        values(%s, %s, %s, %s, %s, %s, %s, %s, 0, 0, 1)"
 mysql_conn_params['is_primary'] = True
 for node in jscfg:
-    if not node.has_key('nodemgr_bin_path'):
-        node['nodemgr_bin_path'] = ''
     role = 'replica'
     if node.get('is_primary', False):
         role = 'source'
-    meta_cursor.execute(stmt, (node['ip'], node['port'], node['user'], node['password'], role, 'fsync', 'OFF', 'OFF', node['nodemgr_bin_path']))
+    meta_cursor.execute(stmt, (node['ip'], node['port'], node['user'], node['password'], role, 'fsync', 'OFF', 'OFF'))
 meta_cursor0.execute("commit")
 meta_cursor.close()
 meta_cursor0.close()
