@@ -50,28 +50,6 @@ def mysql_node_check_mgr(conn_params):
 	conn.close()
 	return row[0], row[1]
 
-def mysql_node_check_rbr(conn_params):
-	conn = connect_mysql(conn_params)
-	mysql_version_check(conn, conn_params)
-
-        csr=conn.cursor()
-        csr.execute("show slave hosts")
-        rows=csr.fetchall()
-        slavecnt = len(rows)
-        csr.close()
-        if slavecnt >= 1:
-            conn.close()
-            return conn_params['ip'], conn_params['port']
-
-        csr=conn.cursor()
-        csr.execute("select HOST, PORT from performance_schema.replication_connection_configuration where channel_name='kunlun_repl'")
-        row = csr.fetchone()
-	if row == None or row[0] == None or row[0] == '' or row[1] == None:
-		raise Exception("ERROR: Node {} disconnected from its shard cluster.".format(str(conn_params)))
-	csr.close()
-	conn.close()
-	return row[0], row[1]
-
 # make sure all nodes are in the same shard and has the same master node
 # return the master node params suitable for mysql connection
 def mysql_shard_check(shard_conn_params, ha_mode):
@@ -83,8 +61,6 @@ def mysql_shard_check(shard_conn_params, ha_mode):
 		node['use_pure'] = True
 		if ha_mode == 'mgr':
                     node_mip, node_mport = mysql_node_check_mgr(node)
-                elif ha_mode == 'rbr':
-                    node_mip, node_mport = mysql_node_check_rbr(node)
                 else:
                     node_mip, node_mport = mysql_node_check_norep(node)
 		if cur_prim_port == 0:
@@ -102,20 +78,17 @@ def mysql_shard_check(shard_conn_params, ha_mode):
 	prim_node['host'] = prim_node['ip']
 	del prim_node['ip']
         # delete invalid properties when connecting.
-	if prim_node.has_key('is_primary'):
-		del prim_node['is_primary']
-	if prim_node.has_key('data_dir_path'):
-		del prim_node['data_dir_path']
-	if prim_node.has_key('nodemgr_bin_path'):
-		del prim_node['nodemgr_bin_path']
+        for attr in ['is_primary', 'data_dir_path', 'nodemgr_bin_path', 'ro_weight', 'master_priority']:
+            if attr in prim_node:
+                del prim_node[attr]
 	return prim_node
 
 if __name__ == '__main__':
 	parser = argparse.ArgumentParser(description='test functions in this file')
 	parser.add_argument('--config', help="shard config file path")
 	parser.add_argument('--meta_config', type=str, help="metadata cluster config file path")
-        parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
-        parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+        parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
+        parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
 
 	args = parser.parse_args()
 
