@@ -20,8 +20,8 @@ parser.add_argument('--meta_config', type=str, help="meta-shard config file path
 parser.add_argument('--cluster_name', type=str)
 parser.add_argument('--cluster_owner', type=str); # owner name, e.g. department/group name, or employee name
 parser.add_argument('--cluster_biz', type=str); # used in which business ?
-parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
-parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep', 'rbr'])
+parser.add_argument('--ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
+parser.add_argument('--meta_ha_mode', type=str, default='mgr', choices=['mgr','no_rep'])
 
 args = parser.parse_args()
 
