@@ -41,7 +41,7 @@ CREATE TABLE `commit_log_template_table` (
   `txn_id` bigint unsigned NOT NULL,
   `next_txn_cmd` enum('commit','abort') NOT NULL,
   `prepare_ts` timestamp(6) default current_timestamp(6),
-  `written_shards` json NOT NULL,
+  `written_shards` json,
   PRIMARY KEY (`id`,`comp_node_id`,`txn_id`),
   UNIQUE KEY `commit_log_unik` (`comp_node_id`,`txn_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8
@@ -103,6 +103,7 @@ CREATE TABLE `db_clusters` (
   `when_created` timestamp NOT NULL DEFAULT CURRENT_TIMESTAMP,
   `business` varchar(120) NOT NULL,
   `memo` text,
+  `status` enum('inuse','deleted') DEFAULT 'inuse',
   `ha_mode` enum('no_rep','mgr','rbr') not null,
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (`name`)
@@ -133,7 +134,7 @@ CREATE TABLE `comp_nodes` (
   `when_created` timestamp NULL DEFAULT (now()),
   `user_name` varchar(64) NOT NULL,
   `passwd` varchar(16) NOT NULL,
-  `status` enum('creating','inactive','active') DEFAULT 'creating',
+  `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
   `svr_node_id` int unsigned NOT NULL,
 
   -- resource limits, 0 means unlimited
@@ -253,7 +254,7 @@ CREATE TABLE `server_nodes` (
   PRIMARY KEY (`id`),
   UNIQUE KEY `hostaddr_dcid_uniq` (`hostaddr`(512),`dc_id`),
   FOREIGN KEY (dc_id) references data_centers(id)
-) ENGINE=InnoDB DEFAULT CHARSET=latin1;
+) ENGINE=InnoDB DEFAULT CHARSET=utf8;
 /*!40101 SET character_set_client = @saved_cs_client */;
 -- Insert a pseudo server row in order to create cluster without registering valid server nodes.
 insert into server_nodes(hostaddr, total_mem, total_cpu_cores) values('pseudo_server_useless',16*1024,8);
@@ -306,6 +307,7 @@ CREATE TABLE `shards` (
   `degrade_conf_state` enum('ON','OFF') DEFAULT 'OFF',
   `degrade_run_state` enum('ON','OFF') DEFAULT 'OFF',
   `degrade_conf_time` int NOT NULL default 0,
+  `status` enum('inuse','deleted') DEFAULT 'inuse',
   `coldbackup_period` varchar(50) NOT NULL default '01:00:00-02:00:00',
   PRIMARY KEY (`id`),
   UNIQUE KEY `name` (db_cluster_id, `name`),
@@ -332,7 +334,7 @@ CREATE TABLE `shard_nodes` (
   `svr_node_id` int unsigned NOT NULL,
   `when_created` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
   `master_priority` smallint NOT NULL default 1,
-  `status` enum('creating','inactive','active') DEFAULT 'creating',
+  `status` enum('creating','inactive','active','deleted','manual_stop') DEFAULT 'creating',
 
   -- resource limits, 0 means unlimited
   cpu_cores smallint unsigned NOT NULL default 0,
@@ -351,7 +353,6 @@ CREATE TABLE `shard_nodes` (
   `backup_node` enum ('OFF', 'ON') DEFAULT 'OFF',
 
   PRIMARY KEY (`id`),
-  UNIQUE KEY `hostaddr_port_svrnodeid_uniq` (`hostaddr`(512),`port`,`svr_node_id`),
   FOREIGN KEY (db_cluster_id) references db_clusters(id),
   FOREIGN KEY (svr_node_id) references server_nodes(id),
   FOREIGN KEY (shard_id) references shards(id)
@@ -455,9 +456,9 @@ create table backup_storage(
 create table cluster_coldbackups (
 	id serial primary key,
 	-- which backup media is this backup stored into ?
-	storage_id int unsigned not null default 0,
+	storage_id int not null default 0,
 	-- which kunlun cluster is this from?
-	cluster_id int unsigned not null default 0,
+	cluster_id int not null default 0,
 	-- which kunlun shard is this from?
 	shard_id int not null default 0,
 	-- which kunlun compute node is this from?
@@ -543,7 +544,8 @@ create table table_move_jobs (
 	tab_file_format enum('logical', 'physical', 'dyn_clone') not null,
 	when_started timestamp(6) not null default current_timestamp(6),
 	when_ended timestamp(6) NULL default null,
-	status enum('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed') not null default 'not_started',
+	status varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
+	stage varchar(128) not null default 'not_started', -- ('not_started', 'dumped', 'transmitted', 'loaded', 'caught_up', 'renamed', 'rerouted', 'done', 'failed'),
 	-- extra info for expanding 
 	memo text default null
 ) ENGINE=InnoDB DEFAULT charset=utf8;
@@ -625,4 +627,14 @@ CREATE TABLE `restore_log` (
   KEY `general_log_id` (`general_log_id`)
 ) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 
+DROP TABLE IF EXISTS `cluster_shard_topology`;
+CREATE TABLE `cluster_shard_topology` (
+  `id` int unsigned NOT NULL AUTO_INCREMENT,
+  `cluster_id` int unsigned NOT NULL,
+  `shard_id` text,
+  `max_commit_log_id` int unsigned NOT NULL,
+  `max_ddl_log_id` int unsigned NOT NULL,
+  `timestamp` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
+  PRIMARY KEY (`id`)
+) ENGINE=InnoDB DEFAULT CHARSET=utf8mb4;
 -- Dump completed on 2020-01-04 11:14:45
