@@ -10,7 +10,6 @@ import argparse
 if __name__ == "__main__":
     parser = argparse.ArgumentParser(description='start the computing node')
     parser.add_argument('--port', type=str, help="Port of the Computing node", required=True)
-    parser.add_argument('--valgrind', help="whether to use valgrind", default=False, action='store_true')
     args = parser.parse_args()
     port = args.port
 
@@ -40,8 +39,5 @@ if __name__ == "__main__":
 
     cmd0 = "export LD_LIBRARY_PATH=" + install_path + "/lib:$LD_LIBRARY_PATH;"
     cmd1 = 'export LD_PRELOAD="' + install_path + '/resources/libjemalloc.so.3.6.0"; ulimit -c unlimited; '
-    prefix = ""
-    if args.valgrind:
-        prefix = "valgrind --leak-check=full --trace-children=yes --undef-value-errors=no "
-    startup_cmd = cmd0 + cmd1 + prefix + install_path + '/bin/postgres -D ' + datadir + " > " + pg_logfp + " 2>&1 &"
+    startup_cmd = cmd0 + cmd1 + install_path + '/bin/postgres -D ' + datadir + " > " + pg_logfp + " 2>&1 &"
     os.system(startup_cmd)
